aboutsummaryrefslogtreecommitdiffstats
path: root/core/test/app.go
diff options
context:
space:
mode:
Diffstat (limited to 'core/test/app.go')
-rw-r--r--core/test/app.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/core/test/app.go b/core/test/app.go
index 327555b..9f030e9 100644
--- a/core/test/app.go
+++ b/core/test/app.go
@@ -280,8 +280,8 @@ Loop:
return nil
}
-// Check provides a backdoor to check status of App with reader lock.
-func (app *App) Check(checker func(*App)) {
+// WithLock provides a backdoor to check status of App with reader lock.
+func (app *App) WithLock(function func(*App)) {
app.confirmedLock.RLock()
defer app.confirmedLock.RUnlock()
app.totalOrderedLock.RLock()
@@ -289,5 +289,5 @@ func (app *App) Check(checker func(*App)) {
app.deliveredLock.RLock()
defer app.deliveredLock.RUnlock()
- checker(app)
+ function(app)
}